TestWeatherStation — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »

# TestWeatherStation

Test connection to weather station.

This is a simple utility to test communication with the weather station. If this doesn’t work, then there’s a problem that needs to be sorted out before trying any of the other programs. Likely problems include not properly installing the USB libraries, or a permissions problem. The most unlikely problem is that you forgot to connect the weather station to your computer!

    usage: python -m pywws.TestWeatherStation [options]
    options are:
          --help           display this help
     -c | --change         display any changes in "fixed block" data
     -d | --decode         display meaningful values instead of raw data
     -h | --history count  display the last "count" readings
     -l | --live           display 'live' data
     -m | --logged         display 'logged' data
     -u | --unknown        display unknown fixed block values
     -v | --verbose        increase amount of reassuring messages
                           (repeat for even more messages e.g. -vvv)

Functions

`main`([argv]) |
`raw_dump`(pos, data) |

`pywws.TestWeatherStation.` `raw_dump`(pos, data)

`pywws.TestWeatherStation.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »